@@ -33,17 +33,17 @@
 #include "audio/dcblocker.h"
 #include "eventthread.h"
 #include "audio/samplerateconverter.h"
-#include "managerimpl.h"
+#include "logger.h"
+#include "manager.h"
 #include "noncopyable.h"
 #include "dbus/configurationmanager.h"
+#include <ctime>
 
 class AlsaThread : public ost::Thread {
     public:
         AlsaThread(AlsaLayer *alsa);
 
-        ~AlsaThread() {
-            terminate();
-        }
+        ~AlsaThread() { terminate(); }
 
         virtual void run();
 
@@ -53,17 +53,15 @@ class AlsaThread : public ost::Thread {
 };
 
 AlsaThread::AlsaThread(AlsaLayer *alsa)
-    : Thread(), alsa_(alsa)
-{
-    setCancel(cancelDeferred);
-}
+    : ost::Thread(), alsa_(alsa)
+{}
 
 /**
  * Reimplementation of run()
  */
 void AlsaThread::run()
 {
-    while (!testCancel()) {
+    while (alsa_->isStarted_) {
         alsa_->audioCallback();
         Thread::sleep(20);
     }
@@ -78,7 +76,7 @@ AlsaLayer::AlsaLayer()
     , ringtoneHandle_(NULL)
     , captureHandle_(NULL)
     , audioPlugin_(audioPref.getPlugin())
-    , IDSoundCards_()
+    // , IDSoundCards_()
     , is_playback_prepared_(false)
     , is_capture_prepared_(false)
     , is_playback_running_(false)
@@ -87,11 +85,14 @@ AlsaLayer::AlsaLayer()
     , is_capture_open_(false)
     , audioThread_(NULL)
 {
+    setCaptureGain(Manager::instance().audioPreference.getVolumemic());
+    setPlaybackGain(Manager::instance().audioPreference.getVolumespkr());
 }
 
 // Destructor
 AlsaLayer::~AlsaLayer()
 {
+    isStarted_ = false;
     delete audioThread_;
 
     /* Then close the audio devices */
@@ -107,7 +108,8 @@ bool AlsaLayer::openDevice(snd_pcm_t **pcm, const std::string &dev, snd_pcm_stre
 
     // Retry if busy, since dmix plugin may not have released the device yet
     for (int tries = 0; tries < MAX_RETRIES and err == -EBUSY; ++tries) {
-        usleep(10000);
+        const struct timespec req = {0, 10000000};
+        nanosleep(&req, 0);
         err = snd_pcm_open(pcm, dev.c_str(), stream, 0);
     }
 
@@ -160,7 +162,7 @@ AlsaLayer::startStream()
         if (not is_playback_open_)
             Manager::instance().getDbusManager()->getConfigurationManager()->errorAlert(ALSA_PLAYBACK_DEVICE);
 
-        if (getIndexOut() != getIndexRing())
+        if (getIndexPlayback() != getIndexRingtone())
             if (!openDevice(&ringtoneHandle_, pcmr, SND_PCM_STREAM_PLAYBACK))
                 Manager::instance().getDbusManager()->getConfigurationManager()->errorAlert(ALSA_PLAYBACK_DEVICE);
     }
@@ -217,7 +219,7 @@ AlsaLayer::stopStream()
 #define ALSA_CALL(call, error) ({ \
 			int err_code = call; \
 			if (err_code < 0) \
-				ERROR("ALSA: "error": %s", snd_strerror(err_code)); \
+				ERROR(error ": %s", snd_strerror(err_code)); \
 			err_code; \
 		})
 
@@ -312,16 +314,16 @@ bool AlsaLayer::alsa_set_params(snd_pcm_t *pcm_handle)
     TRY(snd_pcm_hw_params_any(HW), "hwparams init");
     TRY(snd_pcm_hw_params_set_access(HW, SND_PCM_ACCESS_RW_INTERLEAVED), "access type");
     TRY(snd_pcm_hw_params_set_format(HW, SND_PCM_FORMAT_S16_LE), "sample format");
-    TRY(snd_pcm_hw_params_set_rate_near(HW, &audioSampleRate_, NULL), "sample rate");
+    TRY(snd_pcm_hw_params_set_rate_near(HW, &sampleRate_, NULL), "sample rate");
     TRY(snd_pcm_hw_params_set_channels(HW, 1), "channel count");
     TRY(snd_pcm_hw_params_set_period_size_near(HW, &periodSize, NULL), "period time");
     TRY(snd_pcm_hw_params_set_periods_near(HW, &periods, NULL), "periods number");
     TRY(snd_pcm_hw_params(HW), "hwparams");
 #undef HW
 
-    DEBUG("ALSA: %s using sampling rate %dHz",
+    DEBUG("%s using sampling rate %dHz",
            (snd_pcm_stream(pcm_handle) == SND_PCM_STREAM_PLAYBACK) ? "playback" : "capture",
-           audioSampleRate_);
+           sampleRate_);
 
     snd_pcm_sw_params_t *swparams = NULL;
     snd_pcm_sw_params_alloca(&swparams);
@@ -368,7 +370,7 @@ AlsaLayer::write(void* buffer, int length, snd_pcm_t * handle)
         }
 
         default:
-            ERROR("ALSA: unknown write error, dropping frames: %s", snd_strerror(err));
+            ERROR("Unknown write error, dropping frames: %s", snd_strerror(err));
             stopPlaybackStream();
             break;
     }
@@ -403,12 +405,12 @@ AlsaLayer::read(void* buffer, int toCopy)
                     startCaptureStream();
                 }
 
-            ERROR("ALSA: XRUN capture ignored (%s)", snd_strerror(err));
+            ERROR("XRUN capture ignored (%s)", snd_strerror(err));
             break;
         }
 
         case EPERM:
-            ERROR("ALSA: Can't capture, EPERM (%s)", snd_strerror(err));
+            ERROR("Can't capture, EPERM (%s)", snd_strerror(err));
             prepareCaptureStream();
             startCaptureStream();
             break;
@@ -432,7 +434,21 @@ AlsaLayer::buildDeviceTopo(const std::string &plugin, int card)
 }
 
 std::vector<std::string>
-AlsaLayer::getSoundCardsInfo(int stream)
+AlsaLayer::getAudioDeviceList(AudioStreamDirection dir) const
+{
+    std::vector<HwIDPair> deviceMap(getAudioDeviceIndexMap(dir));
+
+    std::vector<std::string> audioDeviceList;
+    for (std::vector<HwIDPair>::const_iterator iter = deviceMap.begin();
+         iter != deviceMap.end(); ++iter)
+         audioDeviceList.push_back(iter->second);
+
+    return audioDeviceList;
+}
+
+
+std::vector<HwIDPair>
+AlsaLayer::getAudioDeviceIndexMap(AudioStreamDirection dir) const
 {
     snd_ctl_t* handle;
     snd_ctl_card_info_t *info;
@@ -440,12 +456,12 @@ AlsaLayer::getSoundCardsInfo(int stream)
     snd_ctl_card_info_alloca(&info);
     snd_pcm_info_alloca(&pcminfo);
 
-    int numCard = -1 ;
+    int numCard = -1;
 
-    std::vector<std::string> cards_id;
+    std::vector<HwIDPair> audioDevice;
 
     if (snd_card_next(&numCard) < 0 || numCard < 0)
-        return cards_id;
+        return audioDevice;
 
     do {
         std::stringstream ss;
@@ -455,10 +471,11 @@ AlsaLayer::getSoundCardsInfo(int stream)
         if (snd_ctl_open(&handle, name.c_str(), 0) == 0) {
             if (snd_ctl_card_info(handle, info) == 0) {
                 snd_pcm_info_set_device(pcminfo , 0);
-                snd_pcm_info_set_stream(pcminfo, (stream == SFL_PCM_CAPTURE) ? SND_PCM_STREAM_CAPTURE : SND_PCM_STREAM_PLAYBACK);
+                snd_pcm_info_set_stream(pcminfo, (dir == AUDIO_STREAM_CAPTURE) ? SND_PCM_STREAM_CAPTURE : SND_PCM_STREAM_PLAYBACK);
 
-                if (snd_ctl_pcm_info(handle ,pcminfo) < 0)
+                if (snd_ctl_pcm_info(handle ,pcminfo) < 0) {
                     DEBUG(" Cannot get info");
+                }
                 else {
                     DEBUG("card %i : %s [%s]",
                            numCard,
@@ -467,9 +484,9 @@ AlsaLayer::getSoundCardsInfo(int stream)
                     std::string description = snd_ctl_card_info_get_name(info);
                     description.append(" - ");
                     description.append(snd_pcm_info_get_name(pcminfo));
-                    cards_id.push_back(description);
+
                     // The number of the sound card is associated with a string description
-                    IDSoundCards_.push_back(HwIDPair(numCard , description));
+                    audioDevice.push_back(HwIDPair(numCard , description));
                 }
             }
 
@@ -478,7 +495,7 @@ AlsaLayer::getSoundCardsInfo(int stream)
     } while (snd_card_next(&numCard) >= 0 && numCard >= 0);
 
 
-    return cards_id;
+    return audioDevice;
 }
 
 
@@ -503,9 +520,17 @@ AlsaLayer::soundCardIndexExists(int card, int stream)
 }
 
 int
-AlsaLayer::soundCardGetIndex(const std::string &description)
+AlsaLayer::getAudioDeviceIndex(const std::string &description) const
 {
-    for (std::vector<HwIDPair>::const_iterator iter = IDSoundCards_.begin(); iter != IDSoundCards_.end(); ++iter)
+    std::vector<HwIDPair> audioDeviceIndexMap;
+
+    std::vector<HwIDPair> captureDevice = getAudioDeviceIndexMap(AUDIO_STREAM_CAPTURE);
+    std::vector<HwIDPair> playbackDevice = getAudioDeviceIndexMap(AUDIO_STREAM_PLAYBACK);
+
+    audioDeviceIndexMap.insert(audioDeviceIndexMap.end(), captureDevice.begin(), captureDevice.end());
+    audioDeviceIndexMap.insert(audioDeviceIndexMap.end(), playbackDevice.begin(), playbackDevice.end());
+
+    for (std::vector<HwIDPair>::const_iterator iter = audioDeviceIndexMap.begin(); iter != audioDeviceIndexMap.end(); ++iter)
         if (iter->second == description)
             return iter->first;
 
@@ -513,19 +538,10 @@ AlsaLayer::soundCardGetIndex(const std::string &description)
     return 0;
 }
 
-namespace {
-void adjustVolume(SFLDataFormat *src , int samples, int volumePercentage)
-{
-    if (volumePercentage != 100)
-        for (int i = 0 ; i < samples; i++)
-            src[i] = src[i] * volumePercentage * 0.01;
-}
-}
-
 void AlsaLayer::capture()
 {
     unsigned int mainBufferSampleRate = Manager::instance().getMainBuffer()->getInternalSamplingRate();
-    bool resample = audioSampleRate_ != mainBufferSampleRate;
+    bool resample = sampleRate_ != mainBufferSampleRate;
 
     int toGetSamples = snd_pcm_avail_update(captureHandle_);
 
@@ -540,41 +556,39 @@ void AlsaLayer::capture()
     if (toGetSamples > framesPerBufferAlsa)
         toGetSamples = framesPerBufferAlsa;
 
-    int toGetBytes = toGetSamples * sizeof(SFLDataFormat);
-    SFLDataFormat* in = (SFLDataFormat*) malloc(toGetBytes);
+    std::vector<SFLDataFormat> in(toGetSamples);
 
-    if (read(in, toGetBytes) != toGetBytes) {
+    const int toGetBytes = in.size() * sizeof(in[0]);
+    if (read(&(*in.begin()), toGetBytes) != toGetBytes) {
         ERROR("ALSA MIC : Couldn't read!");
-        goto end;
+        return;
     }
 
-    adjustVolume(in, toGetSamples, Manager::instance().getSpkrVolume());
+    AudioLayer::applyGain(&(*in.begin()), toGetSamples, getCaptureGain());
 
     if (resample) {
-        int outSamples = toGetSamples * ((double) audioSampleRate_ / mainBufferSampleRate);
-        int outBytes = outSamples * sizeof(SFLDataFormat);
-        SFLDataFormat* rsmpl_out = (SFLDataFormat*) malloc(outBytes);
-        converter_->resample((SFLDataFormat*) in, rsmpl_out, mainBufferSampleRate, audioSampleRate_, toGetSamples);
-        dcblocker_.process(rsmpl_out, rsmpl_out, outSamples);
-        Manager::instance().getMainBuffer()->putData(rsmpl_out, outBytes);
-        free(rsmpl_out);
+        int outSamples = toGetSamples * ((double) sampleRate_ / mainBufferSampleRate);
+        std::vector<SFLDataFormat> rsmpl_out(outSamples);
+        converter_.resample(&(*in.begin()), &(*rsmpl_out.begin()),
+                rsmpl_out.size(), mainBufferSampleRate, sampleRate_,
+                toGetSamples);
+        dcblocker_.process(&(*rsmpl_out.begin()), &(*rsmpl_out.begin()), outSamples);
+        Manager::instance().getMainBuffer()->putData(&(*rsmpl_out.begin()),
+                rsmpl_out.size() * sizeof(rsmpl_out[0]), MainBuffer::DEFAULT_ID);
     } else {
-        dcblocker_.process(in, in, toGetSamples);
-        Manager::instance().getMainBuffer()->putData(in, toGetBytes);
+        dcblocker_.process(&(*in.begin()), &(*in.begin()), toGetSamples);
+        Manager::instance().getMainBuffer()->putData(&(*in.begin()),
+                toGetBytes, MainBuffer::DEFAULT_ID);
     }
-
-end:
-    free(in);
 }
 
 void AlsaLayer::playback(int maxSamples)
 {
-    unsigned short spkrVolume = Manager::instance().getSpkrVolume();
 
     unsigned int mainBufferSampleRate = Manager::instance().getMainBuffer()->getInternalSamplingRate();
-    bool resample = audioSampleRate_ != mainBufferSampleRate;
+    bool resample = sampleRate_ != mainBufferSampleRate;
 
-    int toGet = Manager::instance().getMainBuffer()->availForGet();
+    int toGet = Manager::instance().getMainBuffer()->availForGet(MainBuffer::DEFAULT_ID);
     int toPut = maxSamples * sizeof(SFLDataFormat);
 
     if (toGet <= 0) {    	// no audio available, play tone or silence
@@ -583,10 +597,12 @@ void AlsaLayer::playback(int maxSamples)
 
         SFLDataFormat *out = (SFLDataFormat *) malloc(toPut);
 
-        if (tone)
-            tone->getNext(out, maxSamples, spkrVolume);
-        else if (file_tone && !ringtoneHandle_)
-            file_tone->getNext(out, maxSamples, spkrVolume);
+        if (tone) {
+            tone->getNext(out, maxSamples, getPlaybackGain());
+        }
+        else if (file_tone && !ringtoneHandle_) {
+            file_tone->getNext(out, maxSamples, getPlaybackGain());
+        }
         else
             memset(out, 0, toPut);
 
@@ -602,7 +618,7 @@ void AlsaLayer::playback(int maxSamples)
     double resampleFactor = 1.0;
 
     if (resample) {
-        resampleFactor = (double) audioSampleRate_ / mainBufferSampleRate;
+        resampleFactor = (double) sampleRate_ / mainBufferSampleRate;
         maxNbBytesToGet = (double) toGet / resampleFactor;
     }
 
@@ -610,16 +626,16 @@ void AlsaLayer::playback(int maxSamples)
         toGet = maxNbBytesToGet;
 
     SFLDataFormat *out = (SFLDataFormat*) malloc(toGet);
-    Manager::instance().getMainBuffer()->getData(out, toGet);
-    adjustVolume(out, toGet / sizeof(SFLDataFormat), spkrVolume);
+    Manager::instance().getMainBuffer()->getData(out, toGet, MainBuffer::DEFAULT_ID);
+    AudioLayer::applyGain(out, toGet / sizeof(SFLDataFormat), getPlaybackGain());
 
     if (resample) {
         int inSamples = toGet / sizeof(SFLDataFormat);
         int outSamples = inSamples * resampleFactor;
-        SFLDataFormat *rsmpl_out = (SFLDataFormat*) malloc(outSamples * sizeof(SFLDataFormat));
-        converter_->resample(out, rsmpl_out, mainBufferSampleRate, audioSampleRate_, inSamples);
-        write(rsmpl_out, outSamples * sizeof(SFLDataFormat), playbackHandle_);
-        free(rsmpl_out);
+        std::vector<SFLDataFormat> rsmpl_out(outSamples);
+        converter_.resample(out, &(*rsmpl_out.begin()), rsmpl_out.size(),
+                            mainBufferSampleRate, sampleRate_, inSamples);
+        write(&(*rsmpl_out.begin()), outSamples * sizeof(SFLDataFormat), playbackHandle_);
     } else {
         write(out, toGet, playbackHandle_);
     }
@@ -632,16 +648,14 @@ void AlsaLayer::audioCallback()
     if (!playbackHandle_ or !captureHandle_)
         return;
 
-    notifyincomingCall();
-
-    unsigned short spkrVolume = Manager::instance().getSpkrVolume();
+    notifyIncomingCall();
 
     snd_pcm_wait(playbackHandle_, 20);
 
     int playbackAvailSmpl = snd_pcm_avail_update(playbackHandle_);
     int playbackAvailBytes = playbackAvailSmpl * sizeof(SFLDataFormat);
 
-    int toGet = urgentRingBuffer_.AvailForGet();
+    int toGet = urgentRingBuffer_.AvailForGet(MainBuffer::DEFAULT_ID);
 
     if (toGet > 0) {
         // Urgent data (dtmf, incoming call signal) come first.
@@ -649,13 +663,13 @@ void AlsaLayer::audioCallback()
             toGet = playbackAvailBytes;
 
         SFLDataFormat *out = (SFLDataFormat*) malloc(toGet);
-        urgentRingBuffer_.Get(out, toGet);
-        adjustVolume(out, toGet / sizeof(SFLDataFormat), spkrVolume);
+        urgentRingBuffer_.Get(out, toGet, MainBuffer::DEFAULT_ID);
+        AudioLayer::applyGain(out, toGet / sizeof(SFLDataFormat), getPlaybackGain());
 
         write(out, toGet, playbackHandle_);
         free(out);
         // Consume the regular one as well (same amount of bytes)
-        Manager::instance().getMainBuffer()->discard(toGet);
+        Manager::instance().getMainBuffer()->discard(toGet, MainBuffer::DEFAULT_ID);
     } else {
         // regular audio data
         playback(playbackAvailSmpl);
@@ -664,17 +678,17 @@ void AlsaLayer::audioCallback()
     if (ringtoneHandle_) {
         AudioLoop *file_tone = Manager::instance().getTelephoneFile();
         int ringtoneAvailSmpl = snd_pcm_avail_update(ringtoneHandle_);
-        int ringtoneAvailBytes = ringtoneAvailSmpl*sizeof(SFLDataFormat);
+        int ringtoneAvailBytes = ringtoneAvailSmpl * sizeof(SFLDataFormat);
 
-        SFLDataFormat *out = (SFLDataFormat *) malloc(ringtoneAvailBytes);
+        std::vector<SFLDataFormat> out(ringtoneAvailSmpl, 0);
 
-        if (file_tone)
-            file_tone->getNext(out, ringtoneAvailSmpl, spkrVolume);
-        else
-            memset(out, 0, ringtoneAvailBytes);
+        if (file_tone) {
+            DEBUG("playback gain %d", getPlaybackGain());
+            file_tone->getNext(&(*out.begin()), ringtoneAvailSmpl,
+                               getPlaybackGain());
+        }
 
-        write(out, ringtoneAvailBytes, ringtoneHandle_);
-        free(out);
+        write(&(*out.begin()), ringtoneAvailBytes, ringtoneHandle_);
     }
 
     // Additionally handle the mic's audio stream
