@@ -41,7 +41,7 @@ Conference::Conference()
     , confState_(ACTIVE_ATTACHED)
     , participants_()
 {
-    Recordable::initRecFileName(id_);
+    Recordable::initRecFilename(id_);
 }
 
 int Conference::getState() const
@@ -71,7 +71,7 @@ void Conference::bindParticipant(const std::string &participant_id)
         if (participant_id != *iter)
             Manager::instance().getMainBuffer()->bindCallID(participant_id, *iter);
 
-    Manager::instance().getMainBuffer()->bindCallID(participant_id);
+    Manager::instance().getMainBuffer()->bindCallID(participant_id, MainBuffer::DEFAULT_ID);
 }
 
 std::string Conference::getStateStr() const
@@ -101,35 +101,31 @@ ParticipantSet Conference::getParticipantList() const
 
 bool Conference::setRecording()
 {
-    bool recordStatus = Recordable::recAudio.isRecording();
+    bool recordStatus = Recordable::recAudio_.isRecording();
 
-    Recordable::recAudio.setRecording();
+    Recordable::recAudio_.setRecording();
     MainBuffer *mbuffer = Manager::instance().getMainBuffer();
 
-    std::string process_id(Recordable::recorder.getRecorderID());
+    std::string process_id(Recordable::recorder_.getRecorderID());
 
     // start recording
     if (!recordStatus) {
         for (ParticipantSet::const_iterator iter = participants_.begin(); iter != participants_.end(); ++iter)
             mbuffer->bindHalfDuplexOut(process_id, *iter);
 
-        mbuffer->bindHalfDuplexOut(process_id);
+        mbuffer->bindHalfDuplexOut(process_id, MainBuffer::DEFAULT_ID);
 
-        Recordable::recorder.start();
+        Recordable::recorder_.start();
     } else {
         for (ParticipantSet::const_iterator iter = participants_.begin(); iter != participants_.end(); ++iter)
             mbuffer->unBindHalfDuplexOut(process_id, *iter);
 
-        mbuffer->unBindHalfDuplexOut(process_id);
+        mbuffer->unBindHalfDuplexOut(process_id, MainBuffer::DEFAULT_ID);
     }
 
     return recordStatus;
 }
 
-std::string Conference::getRecFileId() const {
-    return getConfID();
-}
-
 std::string Conference::getConfID() const {
     return id_;
 }
