@@ -32,17 +32,18 @@
  *  as that of the covered work.
  */
 
-#ifndef __SFL_MANAGER_H__
-#define __SFL_MANAGER_H__
+#ifndef MANAGER_IMPL_H_
+#define MANAGER_IMPL_H_
 
 #include <string>
 #include <vector>
 #include <set>
 #include <map>
-#include <cc++/thread.h>
+#include <tr1/memory>
+#include "cc_thread.h"
 #include "dbus/dbusmanager.h"
 
-#include "config/config.h"
+#include "config/sfl_config.h"
 
 #include "call.h"
 #include "conference.h"
@@ -52,20 +53,18 @@
 
 #include "audio/mainbuffer.h"
 #include "preferences.h"
+#include "history/history.h"
 #include "noncopyable.h"
 
-namespace sfl {
-class InstantMessaging;
-}
-
 namespace Conf {
-class YamlParser;
-class YamlEmitter;
+    class YamlParser;
+    class YamlEmitter;
 }
 
 class DTMF;
 class AudioFile;
 class AudioLayer;
+class History;
 class TelephoneTone;
 class VoIPLink;
 
@@ -73,8 +72,8 @@ class VoIPLink;
 class DNSService;
 #endif
 
-class HistoryManager;
 class Account;
+class SIPAccount;
 
 /** Define a type for a AccountMap container */
 typedef std::map<std::string, Account*> AccountMap;
@@ -82,8 +81,6 @@ typedef std::map<std::string, Account*> AccountMap;
 /** Define a type for a std::string to std::string Map inside ManagerImpl */
 typedef std::map<std::string, std::string> CallAccountMap;
 
-typedef std::map<std::string, Call::CallConfiguration> CallConfigMap;
-
 /** To send multiple string */
 typedef std::list<std::string> TokenList;
 
@@ -96,8 +93,6 @@ static const char * const default_conf = "conf";
 class ManagerImpl {
     public:
         ManagerImpl();
-        ~ManagerImpl();
-
 
         /**
          * General preferences configuration
@@ -133,7 +128,7 @@ class ManagerImpl {
          * Initialisation of thread (sound) and map.
          * Init a new VoIPLink, audio codec and audio driver
          */
-        void init(std::string config_file="");
+        void init(const std::string &config_file);
 
         /**
          * Terminate all thread (sound, link) and unload AccountMap
@@ -215,7 +210,7 @@ class ManagerImpl {
         /**
          * Notify the client the transfer is successful
          */
-        void transferSucceded();
+        void transferSucceeded();
 
         /**
          * Notify the client that the transfer failed
@@ -358,7 +353,7 @@ class ManagerImpl {
          * @param call A call pointer
          * @param accountId an account id
          */
-        void incomingCall(Call* call, const std::string& accountId);
+        void incomingCall(Call &call, const std::string& accountId);
 
         /**
          * Notify the user that the recipient of the call has answered and the put the
@@ -403,19 +398,14 @@ class ManagerImpl {
          */
         void startVoiceMessageNotification(const std::string& accountId, int nb_msg);
 
-        /**
-         * Notify the client through DBus that registration state has been updated
-         */
-        void connectionStatusNotification();
-
         /**
          * ConfigurationManager - Send registration request
          * @param accountId The account to register/unregister
          * @param enable The flag for the type of registration
-         *		 0 for unregistration request
-         *		 1 for registration request
+         *		 false for unregistration request
+         *		 true for registration request
          */
-        void sendRegister(const ::std::string& accountId , const int32_t& enable);
+        void sendRegister(const std::string& accountId, bool enable);
 
         /**
          * Get account list
@@ -468,6 +458,8 @@ class ManagerImpl {
          */
         std::vector<std::string> getParticipantList(const std::string& confID) const;
 
+        std::string getConferenceId(const std::string& callID);
+
         /**
          * Save the details of an existing account, given the account ID
          * This will load the configuration map with the given data.
@@ -579,9 +571,9 @@ class ManagerImpl {
          * Required format: payloads separated with one slash.
          * @return std::string The serializabled string
          */
-        static std::string serialize(const std::vector<std::string> &v);
+        static std::string join_string(const std::vector<std::string> &v);
 
-        static std::vector<std::string> unserialize(std::string v);
+        static std::vector<std::string> split_string(std::string v);
 
         /**
          * Ringtone option.
@@ -695,17 +687,6 @@ class ManagerImpl {
          */
         std::vector <std::string> getAddressbookList() const;
 
-        /**
-         * Hook configuration
-         */
-        std::map<std::string, std::string> getHookSettings() const;
-
-        /**
-         * Hook configuration
-         */
-        void setHookSettings(const std::map<std::string, std::string>& settings);
-
-
         /**
          * Get the audio manager
          * @return int The audio manager
@@ -739,16 +720,6 @@ class ManagerImpl {
          */
         std::vector<std::string> getActiveCodecList() const;
 
-        /**
-         * Retrieve in the configuration tree the value of a parameter in a specific section
-         * @param section	The section to look in
-         * @param name	The name of the parameter you want to get
-         * @param arg	Undocumented
-         * @return bool	true on success
-         *			false otherwise
-         */
-        bool getConfig(const std::string& section, const std::string& name, TokenList& arg) const;
-
         /**
          * Change a specific value in the configuration tree.
          * This value will then be saved in the user config file sflphonedrc
@@ -758,7 +729,7 @@ class ManagerImpl {
          * @return bool	true on success
          *		      false otherwise
          */
-        bool setConfig(const std::string& section, const std::string& name, const std::string& value);
+        void setConfig(const std::string& section, const std::string& name, const std::string& value);
 
         /**
          * Change a specific value in the configuration tree.
@@ -769,27 +740,7 @@ class ManagerImpl {
          * @return bool	true on success
          *		      false otherwise
          */
-        bool setConfig(const std::string& section, const std::string& name, int value);
-
-        /**
-         * Get a int from the configuration tree
-         * Throw an Conf::ConfigTreeItemException if not found
-         * @param section The section name to look in
-         * @param name    The parameter name
-         * @return int    The int value
-         */
-
-        int getConfigInt(const std::string& section, const std::string& name) const;
-
-        /**
-           * Get a bool from the configuration tree
-           * Throw an Conf::ConfigTreeItemException if not found
-           * @param section The section name to look in
-           * @param name    The parameter name
-           * @return bool    The bool value
-           */
-
-        bool getConfigBool(const std::string& section, const std::string& name) const;
+        void setConfig(const std::string& section, const std::string& name, int value);
 
         /**
          * Get a string from the configuration tree
@@ -849,43 +800,7 @@ class ManagerImpl {
          * @return true is there is one or many incoming call waiting
          * new call, not anwsered or refused
          */
-        bool incomingCallWaiting();
-
-        /*
-         * Inline functions to manage speaker volume control
-         * Read by main thread and AudioLayer thread
-         * Write by main thread only
-         * @return unsigned short	The volume value
-         */
-        unsigned short getSpkrVolume() const {
-            return speakerVolume_;
-        }
-
-        /*
-         * Inline functions to manage speaker volume control
-         * Read by main thread and AudioLayer thread
-         * Write by main thread only
-         * @param spkr_vol	The volume value
-         */
-        void setSpkrVolume(unsigned short spkr_vol);
-
-        /*
-         * Inline functions to manage mic volume control
-         * Read by main thread and AudioLayer thread
-         * Write by main thread only
-         * @return unsigned short	The volume value
-         */
-        unsigned short getMicVolume() const {
-            return micVolume_;
-        }
-
-        /*
-         * Inline functions to manage mic volume control
-         * Read by main thread and AudioLayer thread
-         * Write by main thread only
-         * @param mic_vol	The volume value
-         */
-        void setMicVolume(unsigned short mic_vol);
+        bool incomingCallWaiting() const;
 
         /**
          * Return a new random callid that is not present in the list
@@ -909,11 +824,11 @@ class ManagerImpl {
         void initAudioDriver();
 
         void audioLayerMutexLock() {
-            audiolayerMutex_.enterMutex();
+            audioLayerMutex_.enterMutex();
         }
 
         void audioLayerMutexUnlock() {
-            audiolayerMutex_.leaveMutex();
+            audioLayerMutex_.leaveMutex();
         }
 
         /**
@@ -943,19 +858,13 @@ class ManagerImpl {
         /**
          * Create config directory in home user and return configuration file path
          */
-        std::string getConfigFile() const;
-
+        std::string createConfigFile() const;
 
         /*
          * Initialize zeroconf module and scanning
          */
         void initZeroconf();
 
-        /*
-         * Init the volume for speakers/micro from 0 to 100 value
-         */
-        void initVolume();
-
         /**
          * Switch of current call id
          * @param id The new callid
@@ -983,25 +892,24 @@ class ManagerImpl {
         AudioLayer* audiodriver_;
 
         // Main thread
-
-        DTMF* dtmfKey_;
+        std::tr1::shared_ptr<DTMF> dtmfKey_;
 
         /////////////////////
         // Protected by Mutex
         /////////////////////
         ost::Mutex toneMutex_;
-        TelephoneTone* telephoneTone_;
-        AudioFile *audiofile_;
+        std::tr1::shared_ptr<TelephoneTone> telephoneTone_;
+        std::tr1::shared_ptr<AudioFile> audiofile_;
 
         // To handle volume control
-        short speakerVolume_;
-        short micVolume_;
+        // short speakerVolume_;
+        // short micVolume_;
         // End of sound variable
 
         /**
          * Mutex used to protect audio layer
          */
-        ost::Mutex audiolayerMutex_;
+        ost::Mutex audioLayerMutex_;
 
         /**
          * Waiting Call Vectors
@@ -1030,13 +938,6 @@ class ManagerImpl {
          */
         void removeWaitingCall(const std::string& id);
 
-        /**
-         * Tell if a call is waiting and should be remove
-         * @param id std::string to test
-         * @return bool True if the call is waiting
-         */
-        bool isWaitingCall(const std::string& id);
-
         /** Remove a CallID/std::string association
          * Protected by mutex
          * @param callID the CallID to remove
@@ -1060,22 +961,28 @@ class ManagerImpl {
         /** Mutex to lock the call account map (main thread + voiplink thread) */
         ost::Mutex callAccountMapMutex_;
 
-        CallConfigMap callConfigMap_;
+        std::map<std::string, bool> IPToIPMap_;
 
-        bool associateConfigToCall(const std::string& callID, Call::CallConfiguration config);
 
-        Call::CallConfiguration getConfigFromCall(const std::string& callID) const;
-
-        bool removeCallConfig(const std::string& callID);
+        bool isIPToIP(const std::string& callID) const;
 
         /**
          *Contains a list of account (sip, aix, etc) and their respective voiplink/calls */
         AccountMap accountMap_;
 
         /**
-         * Load the account from configuration
+         * Unregister all account in accountMap_
          */
-        void loadAccountMap(Conf::YamlParser *parser);
+        void unregisterAllAccounts();
+
+        /**
+         * Load the account map from configuration
+         */
+        void loadAccountMap(Conf::YamlParser &parser);
+        /**
+         * Load default account map (no configuration)
+         */
+        void loadDefaultAccountMap();
 
         /**
          * Unload the account (delete them)
@@ -1093,13 +1000,15 @@ class ManagerImpl {
 
     public:
 
+        void setIPToIPForCall(const std::string& callID, bool IPToIP);
+
         /** Associate a new std::string to a std::string
          * Protected by mutex
          * @param callID the new CallID not in the list yet
          * @param accountID the known accountID present in accountMap
          * @return bool True if the new association is create
          */
-        bool associateCallToAccount(const std::string& callID, const std::string& accountID);
+        void associateCallToAccount(const std::string& callID, const std::string& accountID);
 
         /**
          * Test if call is a valid call, i.e. have been created and stored in
@@ -1116,13 +1025,6 @@ class ManagerImpl {
             return &mainBuffer_;
         }
 
-        /**
-         * Return a pointer to the instance of InstantMessaging
-         */
-        sfl::InstantMessaging *getInstantMessageModule() {
-            return imModule_;
-        }
-
         /**
          * Tell if there is a current call processed
          * @return bool True if there is a current call
@@ -1145,23 +1047,16 @@ class ManagerImpl {
         */
         bool accountExists(const std::string& accountID);
 
-        /**
-         * Get a list of serialized history entries
-         * @return A list of serialized entry
-         */
-        std::vector<std::string> getHistorySerialized() const;
+        std::vector<std::map<std::string, std::string> > getHistory() const;
+        void clearHistory();
 
-        /**
-         * Set a list of serialized history entries
-         * @param Vector of history entries
-             */
-        void setHistorySerialized(std::vector<std::string> history);
         /**
          * Get an account pointer
          * @param accountID account ID to get
          * @return Account*	 The account pointer or 0
          */
         Account* getAccount(const std::string& accountID);
+        SIPAccount* getIP2IPAccount();
 
         /** Return the std::string from a CallID
          * Protected by mutex
@@ -1179,8 +1074,6 @@ class ManagerImpl {
 
         std::string getAccountIdFromNameAndServer(const std::string& userName, const std::string& server) const;
 
-        int getLocalIp2IpPort() const;
-
         std::string getStunServer() const;
         void setStunServer(const std::string &server);
 
@@ -1194,20 +1087,15 @@ class ManagerImpl {
          * Send registration to all enabled accounts
          */
         void registerAccounts();
+        void saveHistory();
 
     private:
         NON_COPYABLE(ManagerImpl);
 
         /**
           * To handle the persistent history
+          * TODO: move this to ConfigurationManager
           */
-        HistoryManager * history_;
-
-        /**
-         * Instant messaging module, resposible to initiate, format, parse,
-         * send, and receive instant messages.
-         */
-        sfl::InstantMessaging *imModule_;
+        History history_;
 };
-
-#endif // __MANAGER_H__
+#endif // MANAGER_IMPL_H_
