@@ -32,12 +32,14 @@
  *  as that of the covered work.
  */
 
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
 #include <assert.h>
 
+#include "gtk2_wrappers.h"
 #include "eel-gconf-extensions.h"
 #include "dbus.h"
 #include "logger.h"
@@ -346,12 +348,14 @@ static GtkTreeModel* create_model(GtkWidget *widget)
     };
     GdkPixbuf *pixbuf;
     GtkTreeIter iter;
-    gint i, nb_entries;
 
     GtkListStore *store = gtk_list_store_new(3, GDK_TYPE_PIXBUF, G_TYPE_STRING, G_TYPE_INT);
-    nb_entries = sizeof(browser_entries_full) / sizeof(browser_entries_full[0]);
+    gint nb_entries = sizeof(browser_entries_full) / sizeof(browser_entries_full[0]);
+    /* Skip address book entry if that plugin is not installed */
+    if (!addrbook)
+        --nb_entries;
 
-    for (i = 0; i < nb_entries; i++) {
+    for (gint i = 0; i < nb_entries; ++i) {
         gtk_list_store_append (store, &iter);
         pixbuf = get_icon(browser_entries_full[i].icon_name, widget);
         gtk_list_store_set(store, &iter,
@@ -360,7 +364,7 @@ static GtkTreeModel* create_model(GtkWidget *widget)
                            PAGE_NUMBER, browser_entries_full[i].page_number,
                            -1);
         if (pixbuf)
-            gdk_pixbuf_unref(pixbuf);
+            g_object_unref(pixbuf);
     }
 
     return GTK_TREE_MODEL(store);
